summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorAlexander Wenzel <Alexander.AW.Wenzel@bmw.de>2011-11-09 22:04:30 +0100
committerAlexander Wenzel <Alexander.AW.Wenzel@bmw.de>2011-11-09 22:04:30 +0100
commitc9496d17980bbc9a2c5b30742e6ff1ff7ec299b2 (patch)
treed714151f647e5cbe4980fe0f3000fbbc6cdad03e /include
parent4dce943dca5f9f9f49287819504c15ded49e7fc8 (diff)
downloadDLT-daemon-c9496d17980bbc9a2c5b30742e6ff1ff7ec299b2.tar.gz
Added dlt-daemon internal logging configuration into dlt.conf file.
Internal logging to file now also possible.
Diffstat (limited to 'include')
-rwxr-xr-xinclude/dlt/dlt_common.h12
1 files changed, 11 insertions, 1 deletions
diff --git a/include/dlt/dlt_common.h b/include/dlt/dlt_common.h
index 67371be..be315a0 100755
--- a/include/dlt/dlt_common.h
+++ b/include/dlt/dlt_common.h
@@ -862,8 +862,18 @@ extern "C"
int dlt_file_free(DltFile *file,int verbose);
/**
+ * Set internal logging filename if mode 2
+ * @param filename the filename
+ */
+ void dlt_log_set_filename(const char *filename);
+ /**
+ * Set internal logging level
+ * @param level the level
+ */
+ void dlt_log_set_level(int level);
+ /**
* Initialize (external) logging facility
* @param mode positive, if syslog should be used; zero for console output
*/
void dlt_log_init(int mode);
/**
@@ -862,8 +862,18 @@ extern "C"
* Initialize (external) logging facility
- * @param mode positive, if syslog should be used; zero for console output
+ * @param mode positive, 0 = log to stdout, 1 = log to syslog, 2 = log to file
*/
void dlt_log_init(int mode);